@@ -4,10 +4,11 @@ Source: https://github.com/BoboTiG/python-mss
 """
 import glob
 import os
+from pathlib import Path
 
 import pytest
 
-import mss
+from mss import mss
 
 
 @pytest.fixture(autouse=True)
@@ -16,9 +17,7 @@ def no_warnings(recwarn):
 
     yield
 
-    warnings = [
-        "{w.filename}:{w.lineno} {w.message}".format(w=warning) for warning in recwarn
-    ]
+    warnings = ["{w.filename}:{w.lineno} {w.message}".format(w=warning) for warning in recwarn]
     for warning in warnings:
         print(warning)
     assert not warnings
@@ -41,33 +40,18 @@ def before_tests(request):
     request.addfinalizer(purge_files)
 
 
-@pytest.fixture(scope="module")
-def sct():
-    try:
-        # `display` kwarg is only for GNU/Linux
-        return mss.mss(display=os.getenv("DISPLAY"))
-    except TypeError:
-        return mss.mss()
+@pytest.fixture(scope="session")
+def raw() -> bytes:
+    file = Path(__file__).parent / "res" / "monitor-1024x768.raw"
+    return file.read_bytes()
 
 
 @pytest.fixture(scope="session")
-def is_travis():
-    return "TRAVIS" in os.environ
-
-
-@pytest.fixture(scope="session")
-def raw():
-    here = os.path.dirname(__file__)
-    file = os.path.join(here, "res", "monitor-1024x768.raw")
-    with open(file, "rb") as f:
-        yield f.read()
-
-
-@pytest.fixture(scope="module")
-def pixel_ratio(sct):
+def pixel_ratio() -> int:
     """Get the pixel, used to adapt test checks."""
     # Grab a 1x1 screenshot
     region = {"top": 0, "left": 0, "width": 1, "height": 1}
 
-    # On macOS with Retina display, the width will be 2 instead of 1
-    return sct.grab(region).size[0]
+    with mss(display=os.getenv("DISPLAY")) as sct:
+        # On macOS with Retina display, the width will be 2 instead of 1
+        return sct.grab(region).size[0]
